#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xdg-desktop-entry
version:              0.1.1.4
visibility:           public
id:                   xdg-desktop-entry-0.1.1.4-BgGwurxTr4n4YtYhQFp7YJ
key:                  xdg-desktop-entry-0.1.1.4-BgGwurxTr4n4YtYhQFp7YJ
license:              BSD-3-Clause
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:
    https://github.com/taffybar/taffybar/tree/master/packages/xdg-desktop-entry

synopsis:             Parse files conforming to the xdg desktop entry spec
description:          Parse files conforming to the xdg desktop entry spec.
category:             System
abi:                  74aaee8b4a579ccf6945b9942badf855
exposed:              True
exposed-modules:      System.Environment.XDG.DesktopEntry
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xdg-desktop-entry-0.1.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xdg-desktop-entry-0.1.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xdg-desktop-entry-0.1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xdg-desktop-entry
hs-libraries:         HSxdg-desktop-entry-0.1.1.4-BgGwurxTr4n4YtYhQFp7YJ
depends:
    base-4.18.2.1 directory-1.3.8.5 either-5.0.3-EodhgrOgz8CAJ5Cxs0XVgv
    filepath-1.4.300.1 ini-0.4.2-9MI6hRtndBDBgedMb7N5hN
    multimap-1.2.1-4W8aWHvVl9g78Tpaptjwyw
    safe-0.3.21-HhLYFpBFMp3DB0hN62u10D text-2.0.2 transformers-0.6.1.0
    unix-2.8.4.0 unordered-containers-0.2.20.1-1VPUCssH1vYLkUFtdr2cZd

haddock-interfaces:
    /usr/share/doc/haskell-xdg-desktop-entry/html/xdg-desktop-entry.haddock

haddock-html:         /usr/share/doc/haskell-xdg-desktop-entry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

